@@ -13,17 +13,17 @@
 ##############################################################################
 """This module handles the 'preference' namespace directives.
 
-$Id: metaconfigure.py 113366 2010-06-11 17:51:08Z icemac $
 """
 __docformat__ = 'restructuredtext'
 
 from zope.component.zcml import utility
+
 from zope.preference.interfaces import IPreferenceGroup
 from zope.preference.preference import PreferenceGroup
 
 
 def preferenceGroup(_context, id=None, schema=None,
-                    title=u'', description=u'', category=False):
+                    title='', description='', category=False):
     if id is None:
         id = ''
     group = PreferenceGroup(id, schema, title, description, category)
